/*****************************************************
*  
*  Copyright 2010 Akamai Technologies, Inc.  All Rights Reserved.
*  
*****************************************************
*  The contents of this file are subject to the Mozilla Public License
*  Version 1.1 (the "License"); you may not use this file except in
*  compliance with the License. You may obtain a copy of the License at
*  http://www.mozilla.org/MPL/
*   
*  Software distributed under the License is distributed on an "AS IS"
*  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
*  License for the specific language governing rights and limitations
*  under the License.
*   
*  
*  The Initial Developer of the Original Code is Akamai Technologies, Inc.
*  Portions created by Akamai Technologies, Inc. are Copyright (C) 2010 Akamai 
*  Technologies, Inc. All Rights Reserved. 
*  
*****************************************************/
package com.akamai.osmf.samples.service
{
	import com.adobe.serialization.json.JSON;
	import com.akamai.osmf.samples.event.MediaLoadEvent;
	import com.akamai.osmf.utils.AkamaiStrings;
	
	import flash.events.ErrorEvent;
	import flash.events.Event;
	import flash.events.EventDispatcher;
	import flash.events.IOErrorEvent;
	import flash.events.SecurityErrorEvent;
	import flash.net.URLLoader;
	import flash.net.URLRequest;
	
	[Event(name="loaded",	type="com.akamai.osmf.samples.event.MediaLoadEvent")]
	[Event(name="loadFailure", type="com.akamai.osmf.samples.event.MediaLoadEvent")]

	public class MediaSamplesService extends EventDispatcher
	{
		private static const MEDIA_SAMPLES_URL:String =
			//"http://localhost/test/media-samples.json";
			"http://mediapm.edgesuite.net/ovp/content/json/media-samples.json";
		
		public function load():void
		{
			var urlRequest:URLRequest = new URLRequest(MEDIA_SAMPLES_URL);
			var urlLoader:URLLoader = new URLLoader();
			
			setupListeners();
			urlLoader.load(urlRequest);
			
			function setupListeners(add:Boolean=true):void
			{
				if (add)
				{
					urlLoader.addEventListener(Event.COMPLETE, onComplete);
					urlLoader.addEventListener(IOErrorEvent.IO_ERROR, onError);
					urlLoader.addEventListener(SecurityErrorEvent.SECURITY_ERROR, onError);
				}
				else
				{
					urlLoader.removeEventListener(Event.COMPLETE, onComplete);
					urlLoader.removeEventListener(IOErrorEvent.IO_ERROR, onError);
					urlLoader.removeEventListener(SecurityErrorEvent.SECURITY_ERROR, onError);						
				}
			}
			
			function onComplete(event:Event):void
			{
				setupListeners(false);
				var obj:Object = com.adobe.serialization.json.JSON.decode(urlLoader.data);
				
				// Filter out the unknown media types since that 
				// requires an initial resource resolver step
				var resourceArray:Array = new Array();
				for (var i:int = 0; i < obj.samples.length; i++)
				{
					if (obj.samples[i].mediaType != AkamaiStrings.AKAMAI_MEDIA_TYPE_UNKNOWN)
					{
						resourceArray.push(obj.samples[i]);
					}
				}
				
				dispatchEvent(new MediaLoadEvent(MediaLoadEvent.LOADED, false, false, resourceArray));

			}
			
			function onError(event:ErrorEvent):void
			{
				setupListeners(false);
				dispatchEvent(new MediaLoadEvent(MediaLoadEvent.LOAD_FAILURE, false, false, event));
			}
			
		}
	}
}
